@@ -3,6 +3,7 @@ use Mo qw(xxx);
 use YAMLScript::Util;
 
 use boolean;
+use Scalar::Util qw(looks_like_number);
 
 sub define {
     my ($self, $ns) = @_;
@@ -28,6 +29,43 @@ sub define {
         op => '/',
     ],
 
+    [
+        eq =>
+        2 => sub {
+            return looks_like_number($_[0])
+                ? ($_[0] == $_[1])
+                : ($_[0] eq $_[1]);
+        },
+        op => '==',
+    ],
+    [
+        ne =>
+        2 => sub {
+            return looks_like_number($_[0])
+                ? ($_[0] != $_[1])
+                : ($_[0] ne $_[1]);
+        },
+        op => '!=',
+    ],
+    [
+        like =>
+        2 => sub {
+            my ($str, $re) = @_;
+            $re =~ s{^/?(.*?)/?$}{$1};
+            return $str =~ qr($re);
+        },
+        op => '=~',
+    ],
+    [
+        unlike =>
+        2 => sub {
+            my ($str, $re) = @_;
+            $re =~ s{^/?(.*?)/?$}{$1};
+            return $str !~ qr($re);
+        },
+        op => '!~',
+    ],
+
     [
         comment =>
         _ => sub { return },
@@ -111,6 +149,26 @@ sub define {
         lazy => 1,
     ],
 
+    [
+        if =>
+        2 => sub {
+            my ($cond, $then) = @_;
+            if ($cond->call) {
+                $then->call;
+            }
+        },
+        3 => sub {
+            my ($cond, $then, $else) = @_;
+            if ($cond->call) {
+                $then->call;
+            }
+            else {
+                $else->call,
+            }
+        },
+        lazy => 1,
+    ],
+
     [
         len =>
         1 => sub {
